# Data Structure implementation in Python 

A Python package of data structure implementations 

## Usage

This package contains ready to use Data Structure implementations like Stack ,Queue using both arrays and linked lists, Trees ,Graphs etc. The primary focus is provide pre-coded functions that can be used on the go for various coding problems. 

-----------------------------------
**Note:** 
* This package is under development.
* All the files and classes are in title case (eg: TitleCase) and all the methods and functions are in camel case (eg: camelCase)

```  
pip install dimppy
```

-----------------------------------
## Contents
**1.Stack**

**2.Queue**

**3.LinkedList**
* Singly LinkedList
* Doubly LinkedList
* Circular LinkedList

**4.Trees**

**5.Graphs**

**6.HashMap**

**7.Heap**

**8.Searching**
* BinarySearch 
* LinearSearch

**9.Sorting**
* BubbleSort
* BucketSort
* CountSort
* HeapSort
* InsertionSort
* MergeSort
* QuickSort
* RadixSort
* SelectionSOrt
* ShellSort

